%define dist hepx
Summary: The GNU Scientific Library for numerical analysis
Name: gsl1
Version: 1.16
Release: 13%{?dist}2a

BuildArch: fat

URL: http://www.gnu.org/software/gsl/
Source: ftp://ftp.gnu.org/gnu/gsl/gsl-%{version}.tar.gz
Patch0: gsl-1.16-macosx.patch
# info part of this package is under GFDL license
# eigen/nonsymmv.c and eigen/schur.c
# contains rutiens which are part of LAPACK - under BSD style license
License: GPLv3 and GFDL and BSD
Group: System Environment/Libraries
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: pkgconfig
Prefix: /opt/gsl/%{version}

%description
The GNU Scientific Library (GSL) is a collection of routines for
numerical analysis, written in C.

%package devel
Summary: Libraries and the header files for GSL development
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires(post): info
Requires(preun): info
Requires: pkgconfig, automake
Obsoletes: gsl < 2.0

%description devel
The gsl-devel package contains the header files necessary for 
developing programs using the GSL (GNU Scientific Library).

%package static
Summary: Static libraries of the GSL package
Group: Development/Libraries
Requires: %{name}-devel = %{version}-%{release}

%description static
The gsl-static package includes static libraries of GSL.

%prep
%ifos darwin
%setup -q -c -n %{name}-%{version}
pushd gsl-%{version}
%else
%setup -n gsl-%{version} -q
%endif
%patch0 -p1 -b .osx
iconv -f windows-1252 -t utf-8 THANKS  > THANKS.aux
touch -r THANKS THANKS.aux
mv THANKS.aux THANKS
%ifos darwin
cp -p AUTHORS COPYING ChangeLog INSTALL NEWS README THANKS TODO ..
popd
mv gsl-%{version} ARM64
cp -a ARM64 X86_64
%endif

%build
%ifos darwin
for chip in ARM64 X86_64; do
  pushd ${chip}
arch -arch $(echo ${chip} | tr [A-Z] [a-z]) \
./configure \
	--prefix=%{prefix} \
	--sysconfdir=%{_sysconfdir} \
	--localstatedir=%{_localstatedir} \
	--sharedstatedir=%{_sharedstatedir} \
	CC=clang
arch -arch $(echo ${chip} | tr [A-Z] [a-z]) \
make %{?_smp_mflags}
%else
%configure CFLAGS="$CFLAGS -fgnu89-inline"
make %{?_smp_mflags}
%endif
%ifos darwin
  popd
done
%endif


%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%ifos darwin
# start chip loop
for chip in ARM64 X86_64; do
  mkdir ${chip}-root
  pushd ${chip}
%endif
%ifos darwin
  make install DESTDIR=${RPM_BUILD_DIR}/gsl1-%{version}/${chip}-root install='install -p'
%else
make install DESTDIR=$RPM_BUILD_ROOT install='install -p'
%endif
%ifos darwin
popd
done # end chip loop
%endif

%ifos darwin
## Make Universal Binaries
filelist=$(find ./ARM64-root -type f | xargs file | sed -e 's,^\./ARM64-root/,,g' | \
        grep -E \(Mach-O\)\|\(ar\ archive\) |sed -e 's,:.*,,g' -e '/\for\ architecture/d')

mkdir -p tmp_for_lipo
for i in $filelist
do
        /usr/bin/lipo -create ARM64-root/$i X86_64-root/$i -output tmp_for_lipo/`basename $i` && \
        (cp -f tmp_for_lipo/`basename $i` ARM64-root/$i) || :
done

# check header files
for i in `find ARM64-root -name "*.h" -type f`
do
        TARGET=`echo $i | sed -e "s,.*ARM64-root,,"`
        TEMP=`diff -u ARM64-root/$TARGET X86_64-root/$TARGET > /dev/null || echo different`
        if [ -n "$TEMP" ]; then
                mv X86_64-root/$TARGET ARM64-root/${TARGET%.*}-x86_64.h
                mv ARM64-root/$TARGET ARM64-root/${TARGET%.*}-arm64.h
                FILE=${TARGET##*/}
                FILE=${FILE%.*}
cat <<EOF > ARM64-root/$TARGET
#if defined (__arm64__)
#include "${FILE}-arm64.h"
#elif defined( __x86_64__ )
#include "${FILE}-x86_64.h"
#endif
EOF
        fi
done

# install
mkdir -p %{buildroot}
tar cf - -C ARM64-root . | tar xpf - -C %{buildroot}
%endif

# remove unpackaged files from the buildroot
rm -rf $RPM_BUILD_ROOT%{prefix}/share/info/dir
rm -f $RPM_BUILD_ROOT%{prefix}/lib/*.la


%ifnos darwin
%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig
%endif

%post devel
install-info %{prefix}/share/info/gsl-ref.info %{prefix}/share/info/dir || :

%preun devel 
if [ "$1" = 0 ]; then
    install-info --delete %{prefix}/share/info/gsl-ref.info %{prefix}/share/info/dir || :
fi

%clean
rm -rf $RPM_BUILD_ROOT

%files
%ifnos darwin
%defattr(-,root,root,-)
%else
%defattr(-,root,wheel,-)
%endif
%doc AUTHORS COPYING ChangeLog INSTALL NEWS README THANKS TODO
%ifnos darwin
%{prefix}/lib/*so.*
%else
%{prefix}/lib/*.*.dylib
%endif
%{prefix}/bin/gsl-histogram
%{prefix}/bin/gsl-randist
%{prefix}/share/man/man1/gsl-histogram.1*
%{prefix}/share/man/man1/gsl-randist.1*

%files devel
%ifnos darwin
%defattr(-,root,root,-)
%else
%defattr(-,root,wheel,-)
%endif
%doc AUTHORS COPYING
%{prefix}/bin/gsl-config*
%{prefix}/share/aclocal/*
%{prefix}/include/*
%{prefix}/share/info/*info*
%ifnos darwin
%{prefix}/lib/*.so
%else
%{prefix}/lib/*.dylib
%exclude %{prefix}/lib/*.*.dylib
%endif
%{prefix}/lib/pkgconfig/gsl.pc
%{prefix}/share/man/man1/gsl-config.1*
%{prefix}/share/man/man3/*.3*

%files static
%ifnos darwin
%defattr(-,root,root,-)
%else
%defattr(-,root,wheel,-)
%endif
%doc AUTHORS COPYING
%{prefix}/lib/*.a

%changelog
* Wed Nov 22 2023 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-13hepx2a
- 2nd build and release on MacOS 13
- now provided as fat
- built with OSXWS 13 and clang

* Fri Nov 3 2023 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-13hepx1a
- 1st build and release on MacOS 13
- built with OSXWS 13

* Wed Feb 16 2022 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-12hepx1b
- 2nd build and release on MacOS X 12 for M1 Macs
- built with OSXWS 12beta

* Fri Feb 4 2022 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-12hepx1a
- 1st build and release on MacOS X 12 for M1 Macs
- built with OSXWS 11

* Thu Jan 23 2020 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-10.15hepx1a
- 1st build and release on MacOS X 10.15
- built with OSXWS 10.15

* Thu Dec 19 2019 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-10.14hepx1b
- 2nd build and release on MacOS X 10.14
- built with OSXWS 10.14

* Mon Dec 24 2018 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-10.14hepx1a
- 1st build and release on MacOS X 10.14
- built with OSXWS 10.13

* Mon Apr 02 2018 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-10.13hepx1a
- 1st build and release on MacOS X 10.13
- built with OSXWS 10.13

* Mon Dec 26 2016 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-10.12hepx1b
- 2nd build and release on MacOS X 10.12
- built with OSXWS 10.12

* Sun Dec 18 2016 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-10.12hepx1a
- 1st build and release on MacOS X 10.12
- built with OSXWS 10.11

* Fri Oct 21 2016 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-10.10hepx1a
- 1st build and release on MacOS X 10.10
- Renamed to gsl1 to allow coexistence with gsl-2.

* Wed Dec 24 2014 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-10.10hepx1a
- 1st build and release on MacOS X 10.10

* Wed Aug 06 2014 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-10.9hepx1b
- 2nd build and release on MacOS X 10.9

* Tue Nov 19 2013 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.16-10.9hepx1a
- 1st build and release on MacOS X 10.9

* Wed May 02 2012 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.15-10.7hepx1a
- 1st build on MacOS X 10.7
- now built for x86_64

* Sat Sep 24 2011 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.15-10.6hepx1a
- 1st build on MacOS X 10.6
- rebuilt with gcc4.5.1 and libstdc++.dylib

* Wed Jan 26 2011 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.13-10.6hepx1d
- 4th build on MacOS X 10.6
- rebuilt with gcc4.5.1 and libstdc++.dylib

* Sun Nov 14 2010 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.13-10.6hepx1c
- 3rd build on MacOS X 10.6
- rebuilt with gcc4.5.1

* Fri Oct 01 2010 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.13-10.6hepx1b
- 2nd build on MacOS X 10.6
- rebuilt with gcc4.5.1

* Mon Mar 08 2010 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.13-10.6hepx1a
- 1st build on MacOS X 10.6

* Tue Feb 24 2009 Keisuke Fujii <keisuke.fujii@kek.jp> - 1.12-10.5hepx1a
- 1st build on MacOS X 10.5

* Mon Jan 19 2009 Ivana Varekova <varekova@redhat.com> - 1.12-1
- update to 1.12

* Tue Sep 16 2008 Ivana Varekova <varekova@redhat.com> - 1.11-4
- Resolves: #462369 - remove %%{_datadir}/aclocal
- add automake dependency

* Mon Jul 28 2008 Ivana Varekova <varekova@redhat.com> - 1.11-3
- add -fgnu89-inline flag to solve gcc4.3 problem 
  remove gcc43 patch

* Wed Jun 18 2008 Ivana Varekova <varekova@redhat.com> - 1.11-2
- Resolves: #451006
  programs build with gcc 4.3 based on gsl require -fgnu89-inline 

* Mon Jun 16 2008 Ivana Varekova <varekova@redhat.com> - 1.11-1
- update to 1.11

* Wed Feb 20 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.10-10
- Autorebuild for GCC 4.3

* Thu Nov  1 2007 Ivana Varekova <varekova@redhat.com> - 1.10-9
- source file change
- spec cleanup

* Thu Nov  1 2007 Ivana Varekova <varekova@redhat.com> - 1.10-8
- fix man-pages directories

* Tue Oct 30 2007 Ivana Varekova <varekova@redhat.com> - 1.10-7
- add man pages

* Fri Oct 26 2007 Ivana Varekova <varekova@redhat.com> - 1.10-6
- minor spec changes

* Thu Oct 25 2007 Ivana Varekova <varekova@redhat.com> - 1.10-5
- minor spec changes

* Wed Oct 24 2007 Ivana Varekova <varekova@redhat.com> - 1.10-4
- add pkgconfig dependency
- separate static libraries to -static subpackage
- fix gsl-config script - thanks Patrice Dumas

* Sun Sep 23 2007 Ivana Varekova <varekova@redhat.com> - 1.10-3
- remove *.la files
- add pkgconfig configure file
- change source
- spec file cleanup

* Wed Sep 19 2007 Ivana Varekova <varekova@redhat.com> - 1.10-2
- update license tag

* Wed Sep 19 2007 Ivana Varekova <varekova@redhat.com> - 1.10-1
- update to 1.10
- change license tag

* Tue May 22 2007 Ivana Varekova <varekova@redhat.com> - 1.9-1
- update  to 1.9

* Wed Mar 14 2007 Ivana Varekova <varekova@redhat.com> - 1.8-3
- incorporate the package review feedback

* Mon Jan 22 2007 Ivana Varekova <varekova@redhat.com> - 1.8-2
- Resolves: 223700
  fix non-failsafe install-info problem
- spec file cleanup

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.8-1.1
- rebuild

* Fri May  5 2006 Ivana Varekova <varekova@redhat.com> - 1.8-1
- update to 1.8

* Fri Mar  3 2006 Ivana Varekova <varekova@redhat.com> - 1.7-2
- fix multilib problem

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1.7-1.2.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1.7-1.2
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Thu Nov 10 2005 Ivana Varekova <varekova@redhat.com> 1.7-1
- update to 1.7

* Mon Mar  7 2005 Ivana Varekova <varekova@redhat.com> 1.6-2
- rebuilt

* Thu Jan  6 2005 Ivana Varekova <varekova@redhat.com> 1.6-1
- update to 1.6 

* Wed Dec 15 2004 Ivana Varekova <varekova@redhat.com>
- fix bug #142696 gsl-config outputs invalid flags on multilib 64-bit 
architectures

* Fri Jul 02 2004 Florian La Roche <Florian.LaRoche@redhat.de>
- 1.5

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu Aug 21 2003 Florian La Roche <Florian.LaRoche@redhat.de>
- update to 1.4

* Wed Jun 25 2003 Florian La Roche <Florian.LaRoche@redhat.de>
- update to 1.3

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Fri Nov 29 2002 Tim Powers <timp@redhat.com> 1.1.1-4
- remove unpackaged files from the buildroot

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Thu May 23 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Thu Mar 21 2002 Trond Eivind Glomsrød <teg@redhat.com>
- 1.1.1 bugfix release
- Stop the gsl-config script from printing -I/usr/include 
  and -L/usr/lib (#59500)


* Wed Feb 27 2002 Trond Eivind Glomsrød <teg@redhat.com> 1.1-1
- 1.1
- Update URL and location

* Wed Jan 09 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Thu Dec 13 2001 Trond Eivind Glomsrød <teg@redhat.com> 1.0-1
- 1.0
- Split into gsl and gsl-devel
- update description (#56926)

* Thu Jul 19 2001 Preston Brown <pbrown@redhat.com>
- upgrade to 0.9

* Sun Jun 24 2001 Elliot Lee <sopwith@redhat.com>
- Bump release + rebuild.

* Thu Jan 18 2001 Preston Brown <pbrown@redhat.com>
- prereq install-info (#24250)

* Mon Dec 11 2000 Preston Brown <pbrown@redhat.com>
- 0.7, remove excludearch for ia64

* Sun Jul 30 2000 Florian La Roche <Florian.LaRoche@redhat.de>
- fix %%post to be a real shell and add ldconfig to %%post

* Thu Jul 13 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Mon Jun 19 2000 Preston Brown <pbrown@redhat.com>
- don't include the info dir file...

* Sat Jun 17 2000 Bill Nottingham <notting@redhat.com>
- add %%defattr

* Mon Jun 12 2000 Preston Brown <pbrown@redhat.com>
- 0.6, FHS paths
- exclude ia64, it is having issues

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 2)

* Thu Mar 11 1999 Bill Nottingham <notting@redhat.com>
- update to 0.3f
- add patches to fix glibc-2.1 compilation, doc oddity

* Thu Feb 25 1999 Bill Nottingham <notting@redhat.com>
- new summary/description, work around automake oddity

* Tue Jan 12 1999 Michael K. Johnson <johnsonm@redhat.com>
- libtoolize for arm

* Thu Sep 10 1998 Cristian Gafton <gafton@redhat.com>
- spec file fixups

* Sat May 9 1998 Michael Fulbright <msf@redhat.com>
- started with package for gmp from Toshio Kuratomi <toshiok@cats.ucsc.edu>
- cleaned up file list
- fixed up install-info support
